@@ -272,11 +272,11 @@ emit_func_convert_and_escape = template(
 
 class Interpolator(object):
     braces_required_regex = re.compile(
-        r'(?<!\\)\$({(?P<expression>.*)})',
+        r'(\$|\\)?\$({(?P<expression>.*)})',
         re.DOTALL)
 
     braces_optional_regex = re.compile(
-        r'(?<![\\$])\$({(?P<expression>.*)}|(?P<variable>[A-Za-z][A-Za-z0-9_]*))',
+        r'(\$|\\)?\$({(?P<expression>.*)}|(?P<variable>[A-Za-z][A-Za-z0-9_]*))',
         re.DOTALL)
 
     def __init__(self, expression, braces_required, translate=False,
@@ -329,10 +329,18 @@ class Interpolator(object):
             part = text[:m.start()]
             text = text[m.start():]
 
+            skip = text.startswith('$$') or text.startswith('\\$')
+            if skip:
+                part = part + '$'
+
             if part:
-                node = ast.Str(s=part.replace('$$', '$'))
+                node = ast.Str(s=part)
                 nodes.append(node)
 
+            if skip:
+                text = text[2:]
+                continue
+
             if not body:
                 target = name
             else:
@@ -385,7 +393,7 @@ class Interpolator(object):
                 target = template(
                     "translate(msgid, domain=__i18n_domain, context=__i18n_context, target_language=target_language)",
                     msgid=target, mode="eval",
-                    target_language="target_language",
+                    target_language=load("target_language"),
                     )
         else:
             if translate:
@@ -405,7 +413,7 @@ class Interpolator(object):
                 target = template(
                     "translate(msgid, mapping=mapping, domain=__i18n_domain, context=__i18n_context, target_language=target_language)",
                     msgid=ast.Str(s=formatting_string),
-                    target_language=target_language,
+                    target_language=load("target_language"),
                     mapping=ast.Dict(keys=keys, values=values),
                     mode="eval"
                     )
@@ -901,6 +909,7 @@ class Compiler(object):
         'translate': Symbol(simple_translate),
         'decode': Builtin("str"),
         'convert': Builtin("str"),
+        'on_error_handler': Builtin("str")
         }
 
     lock = threading.Lock()
@@ -1148,8 +1157,10 @@ class Compiler(object):
         self._leave_assignment((node.name, ))
 
         error_assignment = template(
-            "econtext[key] = cls(__exc, __tokens[__token][1:3])",
+            "econtext[key] = cls(__exc, __tokens[__token][1:3])\n"
+            "if handler is not None: handler(__exc)",
             cls=ErrorInfo,
+            handler=load("on_error_handler"),
             key=ast.Str(s=node.name),
             )
 
