@@ -353,6 +353,7 @@ class IdentityExpr(object):
 
 class StringExpr(object):
     """Similar to the built-in ``string.Template``, but uses an
+
     expression engine to support pluggable string substitution
     expressions.
 
@@ -384,7 +385,12 @@ class StringExpr(object):
     syntax:
 
     >>> test(StringExpr('\\${name}'))
-    '\\\${name}'
+    '${name}'
+
+    Alternatively, escaping may be done with double dollar symbols.
+
+    >>> test(StringExpr('$${name}'))
+    '${name}'
 
     Multiple interpolations in one:
 
@@ -394,7 +400,7 @@ class StringExpr(object):
     Here's a more involved example taken from a javascript source:
 
     >>> result = test(StringExpr(\"\"\"
-    ... function(oid) {
+    ... function($$, oid) {
     ...     $('#' + oid).autocomplete({source: ${'source'}});
     ... }
     ... \"\"\"))
@@ -402,6 +408,12 @@ class StringExpr(object):
     >>> 'source: source' in result
     True
 
+    The double-dollar escape does not affect non-interpolation
+    expressions.
+
+    >>> 'function($$, oid)' in result
+    True
+
     In the above examples, the expression is evaluated using the
     dummy engine which just returns the input as a string.
 
@@ -411,7 +423,7 @@ class StringExpr(object):
 
     >>> class engine:
     ...     @staticmethod
-    ...     def parse(expression):
+    ...     def parse(expression, char_escape=None):
     ...         class compiler:
     ...             @staticmethod
     ...             def assign_text(target):
@@ -432,7 +444,8 @@ class StringExpr(object):
     We evaluate the expression using the new engine:
 
     >>> test(expr, engine)
-    'There are 11 characters in \"hello world\"'
+    'There are 11 characters in \"hello world\
+"'
     """
 
     def __init__(self, expression, braces_required=False):
@@ -542,7 +555,7 @@ class SimpleEngine(object):
         if expression is not None:
             self.expression = expression
 
-    def parse(self, string, handle_errors=False):
+    def parse(self, string, handle_errors=False, char_escape=None):
         compiler = self.expression(string)
         return SimpleCompiler(compiler, self)
 
